@@ -48,4 +48,4 @@ if __name__ == "__main__":
     path = REPO_PATH
     if len(sys.argv) == 2:
         path = sys.argv[1]
-    print (calculate_contenthash(path))
+    print((calculate_contenthash(path)))
