@@ -27,7 +27,7 @@ def modifyrepo(filename, repodata):
 
 if __name__ == '__main__':
     # Generate the updateinfo.xml
-    execfile('updateinfo_gen_02.py')
+    exec(compile(open('updateinfo_gen_02.py', "rb").read(), 'updateinfo_gen_02.py', 'exec'))
     #OUT_FILE is defined in updateinfo_gen_02.py, it will be OK at runtime.
     modifyrepo(OUT_FILE, REPO_PATH) #pylint: disable=undefined-variable
 
