@@ -46,7 +46,7 @@ def generate():
     ui = cr.UpdateInfo()
     ui.append(rec)
 
-    print( ui.xml_dump(),)
+    print(( ui.xml_dump(),))
 
 if __name__ == "__main__":
     generate()
