@@ -50,7 +50,7 @@ def generate():
     f.add_chunk(chunk)
     f.close()
 
-    print ("See the %s" % OUT_FILE)
+    print(("See the %s" % OUT_FILE))
 
 
 if __name__ == "__main__":
