@@ -237,7 +237,7 @@ static struct PyMethodDef package_methods[] = {
     {"copy", (PyCFunction)copy_pkg, METH_NOARGS, copy__doc__},
     {"__copy__", (PyCFunction)copy_pkg, METH_NOARGS, copy__doc__},
     {"__deepcopy__", (PyCFunction)deepcopy_pkg, METH_VARARGS, copy__doc__},
-    {NULL} /* sentinel */
+    {NULL, NULL, 0, NULL} /* sentinel */
 };
 
 /* Getters */
@@ -377,10 +377,6 @@ set_num(_PackageObject *self, PyObject *value, void *member_offset)
         val = (gint64) PyLong_AsLong(value);
     } else if (PyFloat_Check(value)) {
         val = (gint64) PyFloat_AS_DOUBLE(value);
-#if PY_MAJOR_VERSION < 3
-    } else if (PyInt_Check(value)) {
-        val = (gint64) PyInt_AS_LONG(value);
-#endif
     } else {
         PyErr_SetString(PyExc_TypeError, "Number expected!");
         return -1;
